==> qtjambi-opengl-debuginfo-macos-6.5.4.jar: sources/QtJambiOpenGL/QOpenGLDebugLogger_shell.h <==
#ifndef QOPENGLDEBUGLOGGER_SHELL_H
#define QOPENGLDEBUGLOGGER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtOpenGL/qopengldebug.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


class QOpenGLDebugLogger_shell : public QOpenGLDebugLogger, public QtJambiShellInterface
{
public:
    QOpenGLDebugLogger_shell(QObject* parent0 = nullptr);
    ~QOpenGLDebugLogger_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QOpenGLDebugLogger_access : public QOpenGLDebugLogger
{
};

#endif // QOPENGLDEBUGLOGGER_SHELL_H

==> qtjambi-opengl-debuginfo-macos-6.5.9.jar: sources/QtJambiOpenGL/QOpenGLDebugLogger_shell.h <==
#ifndef QOPENGLDEBUGLOGGER_SHELL_H
#define QOPENGLDEBUGLOGGER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtOpenGL/qopengldebug.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


class QOpenGLDebugLogger_shell : public QOpenGLDebugLogger, public QtJambiShellInterface
{
public:
    QOpenGLDebugLogger_shell(QObject* parent0 = nullptr);
    ~QOpenGLDebugLogger_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QOpenGLDebugLogger_mshell;
    friend class QOpenGLDebugLogger_oshell;
};


class QOpenGLDebugLogger_mshell : public QOpenGLDebugLogger_shell
{
public:
    using QOpenGLDebugLogger_shell::QOpenGLDebugLogger_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QOpenGLDebugLogger_oshell : public QOpenGLDebugLogger_mshell
{
public:
    using QOpenGLDebugLogger_mshell::QOpenGLDebugLogger_mshell;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QOpenGLDebugLogger_access : public QOpenGLDebugLogger
{
};

#endif // QOPENGLDEBUGLOGGER_SHELL_H
